@@ -1,10 +1,10 @@
-import requests
 import time
-import aiohttp
 import asyncio
 
-from .config import create_task_url, app_key
-from .get_answer import get_sync_result, get_async_result
+import aiohttp
+import requests
+
+from python3_anticaptcha import create_task_url, app_key, get_sync_result, get_async_result
 
 
 class FunCaptchaTask:
@@ -50,7 +50,7 @@ class FunCaptchaTask:
 		:return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
 		"""
 		self.task_payload['task'].update({"websiteURL": websiteURL,
-										  "websiteKey": websitePublicKey})
+										  "websitePublicKey": websitePublicKey})
 		# Отправляем на антикапча параметры фанкапич,
 		# в результате получаем JSON ответ содержащий номер решаемой капчи
 		captcha_id = requests.post(create_task_url, json=self.task_payload, **kwargs).json()
@@ -115,7 +115,7 @@ class aioFunCaptchaTask:
 		:return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
 		"""
 		self.task_payload['task'].update({"websiteURL": websiteURL,
-										  "websiteKey": websitePublicKey})
+										  "websitePublicKey": websitePublicKey})
 		# Отправляем на антикапча параметры фанкапич,
 		# в результате получаем JSON ответ содержащий номер решаемой капчи
 		async with aiohttp.ClientSession() as session:
